==> custom-toolbox_24.5.02.tar.xz: BUILD/translations/custom-toolbox_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Custom Toolbox</source>
        <translation>カスタムツールボックス</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>ランチャのカスタマイズ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>アプリの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>これはカスタムランチャです</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>起動時にこのダイヤログを表示する</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Open List File</source>
        <translation>リストファイルを開く</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>List Files (*.list)</source>
        <translation>リストファイル (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>File Selection Error</source>
        <translation>ファイルの選択エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>No file selected. Application will now exit.</source>
        <translation>ファイルを選択していません。アプリケーションを終了します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>File Open Error</source>
        <translation>ファイルを開く際のエラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>ファイルを開けません。再試行しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The file %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Could not open file: </source>
        <translation>次のファイルを開けません: </translation>
    </message>
    <message>
        <source>Application will close.</source>
        <translation type="vanished">アプリケーションを終了します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Version: </source>
        <translation>バージョン：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>カスタムツールボックスは、カスタムランチャの作成ツールです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Could not write file: %1</source>
        <translation>次のファイルに書き込めません：%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>File Removal Error</source>
        <translation>ファイルの削除エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Could not remove file: %1</source>
        <translation>次のファイルを削除できません: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>このアプリでカスタムランチャ（ボタン/アイコンのボックス）を作成できます。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>「起動時にこのダイアログを表示する」チェックボックスを表示しない</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>アプリケーションのセットアップで読み込む .list ファイルのフルパスとファイル名</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
</context>
</TS>

==> custom-toolbox_24.6.tar.xz: BUILD/translations/custom-toolbox_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Custom Toolbox</source>
        <translation>カスタムツールボックス</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>ランチャのカスタマイズ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>アプリの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>これはカスタムランチャです</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>起動時にこのダイヤログを表示する</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Open List File</source>
        <translation>リストファイルを開く</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>List Files (*.list)</source>
        <translation>リストファイル (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>File Selection Error</source>
        <translation>ファイルの選択エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>No file selected. Application will now exit.</source>
        <translation>ファイルを選択していません。アプリケーションを終了します。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>File Open Error</source>
        <translation>ファイルを開く際のエラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>ファイルを開けません。再試行しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>File Not Found</source>
        <translation>ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The file %1 does not exist.</source>
        <translation>ファイル %1 は存在しません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Could not open file: </source>
        <translation>次のファイルを開けません: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Version: </source>
        <translation>バージョン：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>カスタムツールボックスは、カスタムランチャの作成ツールです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Could not write file: %1</source>
        <translation>次のファイルに書き込めません：%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>File Removal Error</source>
        <translation>ファイルの削除エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Could not remove file: %1</source>
        <translation>次のファイルを削除できません: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>このアプリでカスタムランチャ（ボタン/アイコンのボックス）を作成できます。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>「起動時にこのダイアログを表示する」チェックボックスを表示しない</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>アプリケーションのセットアップで読み込む .list ファイルのフルパスとファイル名</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
</context>
</TS>
